read_dim_command

Function read_dim_command 

pub fn read_dim_command<ET: EngineTypes>(
    engine: &mut EngineReferences<'_, ET>,
    is_negative: bool,
    cmd: TeXCommand<ET>,
    token: ET::Token,
) -> TeXResult<ET::Dim, ET>
reads a dimension from some TeXCommand that should correspond to a dimension value (e.g. \dimen or \hsize). If the command is a skip, the base value is taken. If the command is an integer, it looks for an appropriate unit.