read_numeric

Function read_numeric 

pub fn read_numeric<ET: EngineTypes>(
    engine: &mut EngineReferences<'_, ET>,
    skip_eq: bool,
    in_token: &ET::Token,
) -> TeXResult<NumContinuation<ET>, ET>
Takes care of the boilerplate for reading a number/dimension/skip. Expands Tokens until an unexpandable Token is encountered; skips = if skip_eq is true, returns true in the first component if an odd number of --characters is encountered before the first digit, returns in the second component either the ASCII value of the fist simple Token encountered, or the relevant TeXCommand in the case of a control sequence. Spaces are skipped.