read_skip_command

Function read_skip_command 

pub fn read_skip_command<ET: EngineTypes>(
    engine: &mut EngineReferences<'_, ET>,
    is_negative: bool,
    cmd: TeXCommand<ET>,
    token: ET::Token,
) -> TeXResult<Skip<ET::Dim>, ET>
reads a skip from some TeXCommand that should correspond to a skip value (e.g. \skip or \lastskip). If the command only yields an integer or dimension, the remaining components of the skip are read.